==> vcmi_1.4.1+dfsg.orig.tar.xz: vcmi-1.4.1/docs/players/Installation_Android.md <==
< [Documentation](../Readme.md) / Installation on Android

## Step 1: Download and install VCMI

**This app requires original heroes 3 sod / complete files to operate, they are not supplied with this installer. it is recommended to purchase version from gog.com. Heroes 3 "hd edition" (steam version) files are not supported !!!**  
Installation is a two step process, at first you need to install game, then you need to upload Heroes3 original data files into your android device.

- Latest release on Google Play (recommended): <https://play.google.com/store/apps/details?id=is.xyz.vcmi>
- Latest release as .apk file: <https://github.com/vcmi/vcmi/releases/latest>
- Daily builds (unstable): <https://builds.vcmi.download/branch/develop/Android/>

## Step 2: Installing Heroes III data files

- Install Heroes III on your PC or extract Heroes III data files from gog installer
- Connect your device to PC and enable file transfer.
- Copy "Data", "Maps" and "Mp3" from Heroes III to any folder on  mobile device, then open VCMI, select Heroes III data import option, then select the folder where you copied Heroes III data.

## Troubleshooting / known issues

### The game crashes on start

**Please double check that you copied original SoD/Complete game files into your Android Device**  

### I imported game data files, but music in game is missing

**Solution:** Try to run data import again or place Mp3 folder from Heroes III manually to Android/data/is.xyz.vcmi/files/vcmi-data/Mp3

### I installed google play version, but have a problem while installing daily builds

**Solution:** Uninstall google play version first, before installing daily build version.

### I installed play version, but the screen is flashing / blank on its edges

**Solution:** Update app to latest version

### The game always starts in 800x600 resolution, cannot effectively change it, also there is a lot of blank space on my widescreen device

**Solution:** Update app to latest version

## Other problems

Please report about gameplay problem: [Github](https://github.com/vcmi/vcmi/issues), [Help & Bugs](https://forum.vcmi.eu/c/international-board/help-bugs) or [Discord](https://discord.gg/chBT42V). Make sure to specify your device and used version of Android.

==> vcmi_1.6.5+dfsg.orig.tar.xz: vcmi-1.6.5/docs/players/Installation_Android.md <==
# Installation Android

## Step 1: Download and install VCMI

**This app requires original heroes 3 sod / complete files to operate, they are not supplied with this installer. it is recommended to purchase version from gog.com. Heroes 3 "hd edition" (steam version) files are not supported !!!**  
Installation is a two step process, at first you need to install game, then you need to upload Heroes3 original data files into your android device.

- Latest release on Google Play (recommended): <https://play.google.com/store/apps/details?id=is.xyz.vcmi>
- Latest release as .apk file: <https://github.com/vcmi/vcmi/releases/latest>
- Daily builds (unstable): <https://builds.vcmi.download/branch/develop/Android/>

## Step 2: Installing Heroes III data files

- Install Heroes III on your PC or extract Heroes III data files from gog installer
- Connect your device to PC and enable file transfer.
- Copy "Data", "Maps" and "Mp3" from Heroes III to any folder on  mobile device, then open VCMI, select Heroes III data import option, then select the folder where you copied Heroes III data.

gog.com download page:
![GoG-Installer](images/gog_offline_installer.png)

## Troubleshooting / known issues

### The game crashes on start

**Please double check that you copied original SoD/Complete game files into your Android Device**  

### I imported game data files, but music in game is missing

**Solution:** Try to run data import again or place Mp3 folder from Heroes III manually to Android/data/is.xyz.vcmi/files/vcmi-data/Mp3

### I installed google play version, but have a problem while installing daily builds

**Solution:** Uninstall google play version first, before installing daily build version.

### I installed play version, but the screen is flashing / blank on its edges

**Solution:** Update app to latest version

### The game always starts in 800x600 resolution, cannot effectively change it, also there is a lot of blank space on my widescreen device

**Solution:** Update app to latest version

## Other problems

Please report about gameplay problem: [Github](https://github.com/vcmi/vcmi/issues), [Help & Bugs](https://forum.vcmi.eu/c/international-board/help-bugs) or [Discord](https://discord.gg/chBT42V). Make sure to specify your device and used version of Android.
